@@ -3,7 +3,7 @@ package Template::Plugin::TagRescue;
 use strict;
 use HTML::Parser 3.08;
 use vars qw($VERSION);
-$VERSION = 0.02;
+$VERSION = 0.04;
 
 require Template::Plugin;
 use base qw(Template::Plugin);
@@ -26,6 +26,7 @@ sub filter_factory {
 
     return sub {
 	my ($context, @tags) = @_;
+        @tags = map { ref $_ eq 'ARRAY' ? @{$_} : $_ } @tags;
 	reset_vars(@tags);
 	return sub {
 	    $p->parse(shift);
@@ -92,6 +93,11 @@ Template::Plugin::TagRescue - TT Plugin to escape html tags except for marked
   # Output:
   # &lt;B&gt;Bold!&lt;/B&gt; and <I>Italic!</I><BR>
 
+  [% taglist = ['b', 'br']; '<B>Bold!</B> and <I>Italic!</I><BR>' | html_except_for(taglist) %]
+
+  # Output:
+  # <B>Bold!</B> and &lt;I&gt;Italic!&lt;/I&gt;<BR>
+
 =head1 DESCRIPTION
 
 Template::Plugin::TagRescue is a plugin for TT, which allows you to
